summaryrefslogtreecommitdiffstats
path: root/lib/kformula/phantomelement.cc
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kformula/phantomelement.cc')
-rw-r--r--lib/kformula/phantomelement.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/kformula/phantomelement.cc b/lib/kformula/phantomelement.cc
index 2aff0dcd..662ec53d 100644
--- a/lib/kformula/phantomelement.cc
+++ b/lib/kformula/phantomelement.cc
@@ -21,16 +21,16 @@
KFORMULA_NAMESPACE_BEGIN
-PhantomElement::PhantomElement( BasicElement* parent ) : SequenceElement( parent )
+PhantomElement::PhantomElement( BasicElement* tqparent ) : SequenceElement( tqparent )
{
}
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
-void PhantomElement::draw( QPainter&, const LuPixelRect&, const ContextStyle&,
+void PhantomElement::draw( TQPainter&, const LuPixelRect&, const ContextStyle&,
ContextStyle::TextStyle, ContextStyle::IndexStyle,
StyleAttributes&, const LuPixelPoint& )
{
@@ -21,16 +21,16 @@
}
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/